# *EduTK*: a toolkit to create modern exercises for programming tutorials (*Python* version)

[![Version](https://img.shields.io/pypi/v/edutk?color=90b4ed&label=PyPi)](https://q37.info/s/xhgwkn7v) [![Download stats](https://img.shields.io/pypi/dm/edutk.svg)](https://pypistats.org/packages/edutk) [![Stars](https://img.shields.io/github/stars/epeios-q37/edutk-python.svg?style=social)](https://github.com/epeios-q37/edutk-python)[![license: MIT](https://img.shields.io/github/license/epeios-q37/edutk-python)](https://github.com/epeios-q37/edutk-python/blob/master/LICENSE)

This toolkit is an attempt to offer facilities to make modern exercises for programming tutorials.

For more details and for examples of exercises based on this toolkit, go to <https://q37.info/s/cbms43s9>.

This project is based on the [*Atlas* toolkit](https://atlastk.org). Other projects using this toolkit can be found here: <https://q37.info/s/sssznrb4>.
